class sprint:
    global RED
    global PINK
    global PURPLE
    global BLUE
    global LIGHTBLUE
    global BRIGHTBLUE
    global GREEN
    global LIGHTGREEN
    global YELLOW
    global ORANGE
    global WHITE
    RED = "\033[38:5:196m"
    PINK = "\033[38:5:163m"
    PURPLE = "\033[38:5:92m"
    BLUE = "\033[38:5:20m"
    LIGHTBLUE = "\033[38:5:27m"
    BRIGHTBLUE = "\033[38:5:33m"
    GREEN = "\033[38:5:40m"
    LIGHTGREEN = "\033[38:5:82m"
    YELLOW = "\033[38:5:11m"
    ORANGE = "\033[38:5:202m"
    WHITE = "\033[38:5:15m"

    def process(message):
        cmessage = ""
        for i in range(len(message)):
            cmessage += str(message[i])
            cmessage += " "
        return cmessage

    def red(*message):
        print(f"{RED}{sprint.process(message)}{WHITE}")

    def pink(*message):
        print(f"{PINK}{sprint.process(message)}{WHITE}")

    def purple(*message):
        print(f"{PURPLE}{sprint.process(message)}{WHITE}")

    def blue(*message):
        print(f"{BLUE}{sprint.process(message)}{WHITE}")

    def lightblue(*message):
        print(f"{LIGHTBLUE}{sprint.process(message)}{WHITE}")

    def brightblue(*message):
        print(f"{BRIGHTBLUE}{sprint.process(message)}{WHITE}")

    def green(*message):
        print(f"{GREEN}{sprint.process(message)}{WHITE}")

    def lightgreen(*message):
        print(f"{LIGHTGREEN}{sprint.process(message)}{WHITE}")

    def yellow(*message):
        print(f"{YELLOW}{sprint.process(message)}{WHITE}")

    def orange(*message):
        print(f"{ORANGE}{sprint.process(message)}{WHITE}")



class sjson:

    def open(filepath="data.json"):
        import json

        global the_file
        the_file = filepath
        with open(filepath) as f:
            data = json.load(f)
        return data

    def save(data={}, filepath="the_file", formatted=True):
        import json
        from os.path import exists

        if filepath == "the_file":
            filepath == the_file
        if exists(filepath):
            with open(filepath, "w") as f:
                if formatted is True:
                    json.dump(data, f, indent=4)
                else:
                    json.dump(data, f)
            return True
        elif exists(the_file):
            with open(the_file, "w") as f:
                if formatted is True:
                    json.dump(data, f, indent=4)
                else:
                    json.dump(data, f)
            return True
        else:
            from .print import sprint

            sprint.red("No files found try creating one with sjson.new()")

    def new(filename="data.json"):
        from os.path import exists

        presplit = filename.split(".")
        if len(presplit) == 1:
            filename += ".json"
        else:
            filename = presplit
        if not exists(filename):
            split = filename.split(".")
            if len(split) == 1:
                f = open(f"{filename}.json", "w")
                f.write("{}")
                f.close()
                return True
            elif len(split) < 1:
                from .print import sprint

                sprint.red("Filename must not be blank.")
                return False
            else:
                f = open(filename, "w")
                f.write("{}")
                f.close()
                return True
        else:
            return "File already exists"
